Translate Toolkit 3.5.0
***********************

*Released on 27 October 2021*

This release contains improvements and bug fixes.

Changes
=======

Formats and Converters
----------------------

- RC
   
  - Rewritten to pyparsing 3 API

- XLIFF

  - Use double quotes in XML header to comply with default xmllint

General
-------

- Code cleanups from pyupgrade

Contributors
============

This release was made possible by the following people:

Vincent Langlet, Michal Čihař

